@@ -10,7 +10,8 @@
 AutopilotMode <- list(
   FullAuto = 'auto',
   SemiAuto = 'semi',
-  Manual = 'manual')
+  Manual = 'manual',
+  Quick = 'quick')
 
 
 PredictJobStatus <- list(
@@ -23,7 +24,7 @@ PredictJobStatus <- list(
 #' Job statuses
 #'
 #' This is a list that contains the valid values for job status when querying the list of jobs mode.
-#' If you wish, you can specify autopilot modes using the list values, e.g. JobStatus$InProgress
+#' If you wish, you can specify job status modes using the list values, e.g. JobStatus$InProgress
 #' instead of typing the string 'inprogress'. This way you can benefit from autocomplete and not have to
 #' remember the valid optons.
 #'
@@ -39,9 +40,37 @@ JobStatus <- list(
 
 JobFailureStatuses <- c(JobStatus$Error, JobStatus$Aborted)
 
-
+#' Job type
+#'
+#' This is a list that contains the valid values for job type when querying the list of jobs.
+#'
+#' @export
+#'
 JobType <- list(
   FeatureImpact = 'featureImpact',
   Predict = 'predict',
-  Model = 'model'
+  Model = 'model',
+  PrimeRulesets = 'primeRulesets',
+  PrimeDownloadValidation = 'primeDownloadValidation',
+  PrimeModel = 'primeModel'
 )
+
+#' Prime Language
+#'
+#' This is a list that contains the valid values for downloadable code programming languages.
+#'
+#' @export
+#'
+PrimeLanguage <- list(
+  Python = 'Python',
+  Java = 'Java')
+
+#' PostgreSQL drivers
+#'
+#' This is a list that contains the valid values for PostgreSQL drivers.
+#'
+#' @export
+#'
+PostgreSQLdrivers <- list(
+  Unicode = 'PostgreSQL Unicode',
+  ANSI = 'PostgreSQL ANSI')
