@@ -18,7 +18,7 @@
 #' CreateGroupPartition, CreateRandomPartition, CreateStratifiedPartition, and CreateUserPartition.
 #' @param mode Optional, specifies the autopilot mode used to start the
 #' modeling project; valid options are 'auto' (fully automatic,
-#' the current DataRobot default, obtained when mode = NULL), 'semi' (semi is deprecated in 2.3, will be removed in 3.0), and 'manual'
+#' the current DataRobot default, obtained when mode = NULL), 'semi' (semi is deprecated in 2.3, will be removed in 3.0), 'manual' and 'quick'
 #' @param seed Optional integer seed for the random number generator used in
 #' creating random partitions for model fitting.
 #' @param positiveClass Optional target variable value corresponding to a positive
@@ -34,7 +34,7 @@
 #' @param recommenderItemId Optional character string, giving the name of the data
 #' column containing item ID's (for recommender models only).
 #' @param quickrun Optional logcial variable; if TRUE then DR will perform
-#' a quickrun, limiting the number of models evaluated during autopilot.
+#' a quickrun, limiting the number of models evaluated during autopilot. (quickrun flag is deprecated in 2.4, will be removed in 3.0)
 #' @param featurelistId Specifies which feature list to use. If NULL (default),
 #' a default featurelist is used.
 #' @param maxWait Specifies how many seconds to wait for the server to finish
@@ -56,6 +56,16 @@ SetTarget <- function(project, target, metric = NULL, weights = NULL,
     if (!is.null(mode) && mode == AutopilotMode$SemiAuto){
       Deprecated("semi mode (use auto or manual mode instead)", "2.3", "3.0")
     }
+    if (!is.null(quickrun)){
+      Deprecated("quickrun flag (use quick autopilot mode instead)", "2.4", "3.0")
+    }
+
+    if (!is.null(mode) && mode == AutopilotMode$Quick){
+      mode <- AutopilotMode$FullAuto
+      quickrun <- TRUE
+    }
+
+
     projectId <- ValidateProject(project)
     routeString <- UrlJoin("projects", projectId, "aim")
     #
